==> haskell-digest-0.0.1.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: digest
version: 0.0.1.2
id: digest-0.0.1.2-HOOuiTuLi6KcgGq1Yeuws
key: digest-0.0.1.2-HOOuiTuLi6KcgGq1Yeuws
license: BSD3
copyright: (c) 2009 Eugene Kirpichov
maintainer: Eugene Kirpichov <ekirpichov@gmail.com>
stability: provisional
synopsis: Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.
description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.
category: Cryptography
author: Eugene Kirpichov <ekirpichov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32
abi: 9d53badb1443a6fc87443c20a2db3082
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/digest-0.0.1.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/digest-0.0.1.2
hs-libraries: HSdigest-0.0.1.2-HOOuiTuLi6KcgGq1Yeuws
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html: /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digest-0.0.1.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: digest
version: 0.0.1.2
id: digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu
key: digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu
license: BSD3
copyright: (c) 2009 Eugene Kirpichov
maintainer: Eugene Kirpichov <ekirpichov@gmail.com>
stability: provisional
synopsis: Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.
description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.
category: Cryptography
author: Eugene Kirpichov <ekirpichov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32
abi: eab7be5e6f9050cf3e35eedfbc3456e9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/digest-0.0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/digest-0.0.1.2
hs-libraries: HSdigest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html: /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
